@@ -39,8 +39,8 @@
 #'
 #' @export
 tiledb_array_create <- function(uri, schema, encryption_key) {
-    stopifnot(`The 'uri' argument must be a string scalar` = !missing(uri) && is.scalar(uri, "character"),
-              `The 'schema' argument must be a tiledb_array_schema object` = !missing(schema) && is(schema, "tiledb_array_schema"))
+    stopifnot("The 'uri' argument must be a string scalar" = !missing(uri) && is.scalar(uri, "character"),
+              "The 'schema' argument must be a tiledb_array_schema object" = !missing(schema) && is(schema, "tiledb_array_schema"))
     if (missing(encryption_key)) {
         invisible(libtiledb_array_create(uri, schema@ptr))
     } else {
