@@ -1,8 +1,6 @@
 library(tinytest)
 library(tiledb)
 
-isOldWindows <- Sys.info()[["sysname"]] == "Windows" && grepl('Windows Server 2008', osVersion)
-
 ctx <- tiledb_ctx(limitTileDBCores())
 
 if (get_return_as_preference() != "asis") set_return_as_preference("asis") 		# baseline value
@@ -97,28 +95,21 @@ expect_error(tiledb:::libtiledb_array_schema_set_capacity(sch@ptr, -10))
 
 
 #test_that("tiledb_array_schema created with encryption",  {
-if (!(isOldWindows)) {
-  dir.create(uri <- tempfile())
-  key <- "0123456789abcdeF0123456789abcdeF"
+dir.create(uri <- tempfile())
+key <- "0123456789abcdeF0123456789abcdeF"
 
-  dom <- tiledb_domain(dims = c(tiledb_dim("rows", c(1L, 4L), 4L, "INT32"),
-                                tiledb_dim("cols", c(1L, 4L), 4L, "INT32")))
-  schema <- tiledb_array_schema(dom, attrs = c(tiledb_attr("a", type = "INT32")))
+dom <- tiledb_domain(dims = c(tiledb_dim("rows", c(1L, 4L), 4L, "INT32"),
+                              tiledb_dim("cols", c(1L, 4L), 4L, "INT32")))
+schema <- tiledb_array_schema(dom, attrs = c(tiledb_attr("a", type = "INT32")))
 
-  ##tiledb_array_create_with_key(uri, schema, key)
-  ## for now calling into function
-  tiledb:::libtiledb_array_create_with_key(uri, schema@ptr, key)
+##tiledb_array_create_with_key(uri, schema, key)
+## for now calling into function
+tiledb:::libtiledb_array_create_with_key(uri, schema@ptr, key)
 
-#  ctx <- tiledb_ctx()
-#  arrptr <- tiledb:::libtiledb_array_open_with_key(ctx@ptr, uri, "WRITE", key)
-#  A <- new("tiledb_dense", ctx=ctx, uri=uri, as.data.frame=FALSE, ptr=arrptr)
+##expect_true(is(schema(A), "tiledb_dense"))
+## can't yet read / write as scheme getter not generalized for encryption
 
-#  expect_true(is(A, "tiledb_dense"))
-  ##expect_true(is(schema(A), "tiledb_dense"))
-  ## can't yet read / write as scheme getter not generalized for encryption
-
-  unlink(uri, recursive=TRUE)
-}
+unlink(uri, recursive=TRUE)
 #})
 
 #test_that("tiledb_array_schema dups setter/getter",  {
