@@ -1,8 +1,6 @@
 library(tinytest)
 library(tiledb)
 
-isOldWindows <- Sys.info()[["sysname"]] == "Windows" && grepl('Windows Server 2008', osVersion)
-if (isOldWindows) exit_file("skip this file on old Windows releases")
 isMacOS <- (Sys.info()['sysname'] == "Darwin")
 
 ctx <- tiledb_ctx(limitTileDBCores())
@@ -56,9 +54,8 @@ while (deltat < 30) {
         isTRUE(all.equal(NROW(res5), 20)) && 		            # expects 2 groups, 2 and 3, with 20 obs
         isTRUE(all.equal(min(res5$grp), 2)) &&
         isTRUE(all.equal(max(res5$grp), 3))) {
-        if (Sys.getenv("CI") != "") message("Success with gap time of ", deltat)
-        success <- TRUE
-        break
+           success <- TRUE
+           break
     }
     deltat <- deltat * 5
 }
@@ -158,3 +155,42 @@ fi <- tiledb_fragment_info(uri)
 expect_equal(as.numeric(tiledb_fragment_info_get_timestamp_range(fi,0))*1000, c(1,1))
 expect_equal(as.numeric(tiledb_fragment_info_get_timestamp_range(fi,1))*1000, c(2,2))
 expect_equal(as.numeric(tiledb_fragment_info_get_timestamp_range(fi,2))*1000, c(3,3))
+
+
+## tests formerly in test_timetravel_extra.R
+
+## earlier time travel test recast via timestamp_{start,end}
+## time travel
+
+tmp <- tempfile()
+dir.create(tmp)
+dom <- tiledb_domain(dims = c(tiledb_dim("rows", c(1L, 10L), 5L, "INT32"),
+                              tiledb_dim("cols", c(1L, 10L), 5L, "INT32")))
+schema <- tiledb_array_schema(dom, attrs=c(tiledb_attr("a", type = "INT32")), sparse = TRUE)
+invisible( tiledb_array_create(tmp, schema) )
+
+I <- c(1, 2, 2)
+J <- c(1, 4, 3)
+data <- c(1L, 2L, 3L)
+now1 <- as.POSIXct(60, tz="UTC") 		# the epoch plus one minute
+A <- tiledb_array(uri = tmp, timestamp_start=now1, timestamp_end=now1)
+A[I, J] <- data
+
+deltat <- 1 							# delta of 1 second
+epst <- deltat/2
+
+I <- c(8, 6, 9)
+J <- c(5, 7, 8)
+data <- c(11L, 22L, 33L)
+now2 <- Sys.time()
+A <- tiledb_array(uri = tmp, timestamp_start=now2, timestamp_end=now2)
+A[I, J] <- data
+
+A <- tiledb_array(uri = tmp, return_as="data.frame", timestamp_end=now1 - epst)
+expect_equal(nrow(A[]), 0) 			# no rows before start
+A <- tiledb_array(uri = tmp, return_as="data.frame", timestamp_start=now1 + epst)
+expect_equal(nrow(A[]), 3) 			# three rows in first write at now1
+A <- tiledb_array(uri = tmp, return_as="data.frame", timestamp_start=now1 - epst, timestamp_end=now2 - epst)
+expect_equal(nrow(A[]), 3)			# three rows if end before now2
+A <- tiledb_array(uri = tmp, return_as="data.frame", timestamp_start=now1 - epst, timestamp_end=now2 + epst)
+expect_true(nrow(A[]) >= 3)			# all data from before now1 to after now2
