@@ -40,8 +40,7 @@ mkdir build
 cd build
 export AWSSDK_ROOT_DIR=/usr
 ../bootstrap --prefix=/usr/local --enable-s3 --enable-serialization --linkage=shared
-make -j 8
-make -C tiledb install
+make -j 8 tiledb install-tiledb
 ldconfig
 cd ../..
 rm -rf tiledb
